#
# spec file for package SimGear
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# We want specific versions of the devel and plugins OpenSceneGraph subpackages
# in our requirements, i.e. the same version we have built against
%define openscenegraph_version %(rpm -qa --nosignature --nodigest libOpenSceneGraph\*-devel | sed 's/.*-devel-\\(.*\\)-.*/\\1/')

%define libname libSimGearCore-2020_3_19
%define main_version 2020.3
Name:           SimGear
Version:        %{main_version}.19
Release:        1.2
Summary:        Simulator Construction Gear
# https://sourceforge.net/p/flightgear/codetickets/1940/
License:        GPL-2.0-or-later AND LGPL-2.0-or-later AND MIT
Group:          Amusements/Games/3D/Simulation
URL:            https://www.flightgear.org/
Source0:        https://sourceforge.net/projects/flightgear/files/release-%{main_version}/simgear-%{version}.tar.bz2
Source99:       SimGear-rpmlintrc
# PATCH-FIX-UPSTREAM simgear-boost-1.81.patch - fix building with boost >= 1.81
Patch0:         simgear-boost-1.81.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  libOpenSceneGraph-devel
BuildRequires:  libboost_headers-devel
BuildRequires:  pkgconfig
BuildRequires:  udns-devel
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(zlib)

%description
SimGear is a set of open-source libraries designed to be used as building
blocks for quickly assembling 3D simulations, games, and visualization
applications.

SimGear is developed as part of the FlightGear project and used by the
FlightGear flight simulator and many of its related utilities.

%package -n %{libname}
Summary:        Simulator Construction Gear
Group:          Amusements/Games/3D/Simulation
Requires:       OpenSceneGraph-plugins = %{openscenegraph_version}

%description -n %{libname}
SimGear is a set of open-source libraries designed to be used as building
blocks for quickly assembling 3D simulations, games, and visualization
applications.

SimGear is developed as part of the FlightGear project and used by the
FlightGear flight simulator and many of its related utilities.

%package devel
Summary:        Development libraries and headers for SimGear
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
BuildRequires:  libboost_headers-devel
Requires:       libOpenSceneGraph-devel = %{openscenegraph_version}
Requires:       udns-devel
Requires:       pkgconfig(liblzma)
Requires:       pkgconfig(openal)
Requires:       pkgconfig(zlib)

%description devel
Development headers and libraries for building applications against
SimGear.

%prep
%autosetup -p1 -n simgear-%{version}

%build
export CFLAGS="%{optflags}"
export CXXFLAGS="%{optflags}"
# configure to build shared simgear libraries
%cmake \
	-DSIMGEAR_SHARED:BOOL=ON \
	-DSYSTEM_EXPAT:BOOL=ON \
	-DSYSTEM_UDNS:BOOL=ON \
	-DENABLE_OPENMP:BOOL=ON \
	-DENABLE_TESTS:BOOL=OFF

%cmake_build

%install
%cmake_install
install -m 755 -d %{buildroot}%{_docdir}/%{name}
install -m 644 -t %{buildroot}%{_docdir}/%{name} AUTHORS ChangeLog NEWS README

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%license COPYING
%{_libdir}/libSimGear*.so.*

%files devel
%doc %{_docdir}/%{name}
%{_includedir}/simgear/
%{_libdir}/libSimGear*.so
%{_libdir}/cmake/SimGear/

%changelog
* Mon Nov 13 2023 Florian "spirit" <packaging@sp1rit.anonaddy.me>
- Update to 2020.3.19
  * https://wiki.flightgear.org/Changelog_2020.3#2020.3.19
* Wed Mar 29 2023 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2020.3.18
  * https://wiki.flightgear.org/Changelog_2020.3#2020.3.18
* Sat Mar  4 2023 Carsten Ziepke <kieltux@gmail.com>
- Add simgear-boost-1.81.patch, fix building with boost >= 1.81
* Wed Nov 23 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2020.3.17
  * https://wiki.flightgear.org/Changelog_2020.3#2020.3.17
* Tue Apr 12 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2020.3.13
  * https://wiki.flightgear.org/Changelog_2020.3#2020.3.13
* Fri Feb  4 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2020.3.12
  * https://wiki.flightgear.org/Changelog_2020.3#2020.3.12
* Thu Aug 26 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2020.3.11
  * https://wiki.flightgear.org/Changelog_2020.3#2020.3.11
* Thu Jun 10 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2020.3.9
  * https://wiki.flightgear.org/Changelog_2020.3#2020.3.9
* Mon Apr  5 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2020.3.8
  * http://wiki.flightgear.org/Changelog_2020.3#2020.3.7
* Thu Jan 28 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2020.3.6
  * http://wiki.flightgear.org/Changelog_2020.3#2020.3.6
- Drop upstream boost-1.75-fix.patch
* Mon Jan 11 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2020.3.5
  * http://wiki.flightgear.org/Changelog_2020.3#2020.3.5
- Fix build with Boost 1.75, add boost-1.75-fix.patch
* Thu Dec 10 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2020.3.4
  * No changelog available
* Thu Nov 12 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2020.3.2
  * No changelog available
* Wed Oct 28 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2020.3.1
  * http://wiki.flightgear.org/Changelog_2020.3
* Sat Jun 27 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2020.1.3
  * http://wiki.flightgear.org/Changelog_2020.1#2020.1.3_point_release
* Thu May 28 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2020.1.2
  * http://wiki.flightgear.org/Changelog_2020.1#2020.1.2_point_release
* Tue May 12 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2020.1.1
  * changelog: http://wiki.flightgear.org/Changelog_2020.1
- Drop upstream patches:
  * 0001-Always-add-PROJECT_BINARY_DIR-to-include_directories.patch
  * 0001-Remove-deprecated-boost-utility.patch
  * 0001-boost-enable_if-Support-Boost-versions-1.56.patch
* Sat May  9 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2018.3.5
  * changelog: http://wiki.flightgear.org/Changelog_2018.3#2018.3.5_point_release
* Thu Sep 26 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix build with cmake 3.15 due to https://cmake.org/cmake/help/v3.15/policy/CMP0093.html
  0001-Always-add-PROJECT_BINARY_DIR-to-include_directories.patch
- Use system expat and udns libraries
- Enable OpenMP support
* Fri Aug 16 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2018.3.4
  * changelog: http://wiki.flightgear.org/Changelog_2018.3#2018.3.4_point_release
- Drop upstream patches:
  * 0001-Improve-HTTP-redirect-handling-and-add-test.patch
* Thu Mar 21 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix building with booost 1.69:
  * Add 0001-Remove-deprecated-boost-utility.patch
  * Add 0001-boost-enable_if-Support-Boost-versions-1.56.patch
* Mon Mar  4 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix redirect handling, add
  0001-Improve-HTTP-redirect-handling-and-add-test.patch
* Mon Feb 11 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2018.3.2
  * changelog: http://wiki.flightgear.org/Changelog_2018.3#2018.3.2_point_release
* Tue Dec 18 2018 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2018.3.1
  * changelog: see upstream, http://wiki.flightgear.org/Changelog_2018.3
- Drop upstream 0001-Add-missing-return-value.patch
* Thu Jul 19 2018 stefan.bruens@rwth-aachen.de
- Adjust BuildRequires and Requires
  * Use BuildConflicts to force a OSG version >= 3.2
  * Drop BuildRequires for OSG plugins, not needed
  * Add versioned Requires: openSceneGraph-plugins. We want plugins
    with the same version as the linked library
- Use %%license for COPYING
* Sun Jul  1 2018 stefan.bruens@rwth-aachen.de
- Fix failing build, no-return-in-nonvoid-function
  0001-Add-missing-return-value.patch
- Change BuildRequires, OpenSceneGraph 3.6 has an incompatible API
* Wed Jun 27 2018 Mathias.Homann@opensuse.org
- Update to 2018.2.2
  * changelog: see upstream, http://wiki.flightgear.org/Changelog_2018.2
  * Fixes boo#1099288 (update requested)
* Fri May  4 2018 Mathias.Homann@opensuse.org
- Update to 2018.1.1
  * changelog: see upstream, http://wiki.flightgear.org/Changelog_2018.1
* Wed Jan  3 2018 rpm@fthiessen.de
- Fixed dependencies
* Tue Dec  5 2017 stefan.bruens@rwth-aachen.de
- Drop lots of unused BuildRequires, as a side effect, fixes building
  on Factory (as it no longer requires openSSL 1_0_0 and 1_1_0)
- Remove no longer used/known -DJPEG_FACTORY:BOOL=ON
* Tue Sep 26 2017 Mathias.Homann@opensuse.org
- Update to 2017.3.1
  * Change API for thumbnail access, so each variant can have a
    unique thumbnail alongside other data. Map existing catalog
    XML format to this system.
  * New alternative terrain engine - SGMesh utilizing pagedLOD.
  * OSG 3.5.x support
  * Package APIs to support multiple primary aircraft, this
    will allow packages to supply multiple primary aircraft.
  * Fix bug "dns timeout, no terrasync servers found"
  * Allow animations to take an object as the centre and axis.
  * Fix mesh visibility on pick animations.
  * Fix animation axis text for new calling conventions.
  * Enable display lists for random trees.
  * Add efficient hasTag check to Package.
  * Persistent thumbnail cache for aircraft packages.
  * Clear Uniform cache on reset.
* Thu Mar  9 2017 wk@ire.pw.edu.pl
- Update to 2017.1.2
* Fri Jan 27 2017 rpm@fthiessen.de
- Fixed spec file
  * Fixed libname
  * Do not spawn an extra bash process for ldconfig
* Wed Jan 11 2017 rpm@fthiessen.de
- Update to 2016.4.4
- Removed upstream merged fix_cmake_config_package_location.patch
* Sun Aug 21 2016 mailaender@opensuse.org
- Update to 2016.2.1
* Sun Mar 20 2016 bosim@opensuse.org
- Added SourceURL
* Mon Mar 14 2016 bosim@opensuse.org
- Update to 2016.1.1
* Sun Mar 13 2016 bosim@opensuse.org
- Fixed missing dependency on OpenSceneGraph-plugins.
* Wed Feb 24 2016 code@hector.link
- Fix CMakeLists.txt to correctly use lib64 for some files
- Fix spec file as /usr/share/SimGearCore is no longer used
* Mon Nov 23 2015 rpm@fthiessen.de
- Update to 3.7.0 (for flightGear 3.7.0).
* Mon Sep 23 2013 Mathias.Homann@opensuse.org
- update: flightGear 2.12 has been released
* Fri Mar  8 2013 joop.boonen@opensuse.org
- update to 2.10.0
- Corrected the license and group
* Fri Aug 17 2012 thorstenb@flightgear.org
- update to 2.8.0
* Fri Feb 17 2012 thorstenb@flightgear.org
- update to 2.6.0
- switched to cmake build system with shared libraries
* Thu Feb  2 2012 highwaystar.ru@gmail.com
- added autotools BuildRequires for build on current Factory
* Mon Jan 30 2012 highwaystar.ru@gmail.com
- fixed OpenSceneGraph-plugins version require (bnc#717918)
* Sat Nov 26 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
* Fri Nov 11 2011 thorstenb@flightgear.org
- added SVN dependency to enable built-in scenery download
* Mon Sep  5 2011 highwaystar.ru@gmail.com
- update to 2.4.0
- shared lib patch reworked
* Tue Apr 12 2011 Rene.vanPaassen@gmail.com
- fixed required plib libraries in simgear/screen/Makefile.am
* Wed Oct 27 2010 prusnak@opensuse.org
- fix OpenSceneGraph requirements for 11.3+
* Mon Mar  1 2010 prusnak@suse.cz
- import SimGear Fedora package by Fabrice Bellet <fabrice@bellet.info>
